@@ -5,12 +5,17 @@ from am_red_channel._consts import *
 def AM_SendDataSameDevice(id, data):
     id_url = k_AM_localNodeURL + str(id)    
     
-    hConfigurations={
-        'Content-Type': k_AM_contentType
+    hConfigurations = {
+        'Content-Type': k_AM_contentType,
+    }
+    
+    params = {          
+        'AM_Auth_Token': 'Amr Mostafa (Amr_MAM)', 
+        'AM_Auth_Signature': 'AM-from-Python',
     }
 
     try:
-        response  = _req.request(k_AM_SEND, id_url, headers=hConfigurations, data = str(data))
+        response  = _req.request(k_AM_SEND, id_url, headers=hConfigurations, params=params, data = str(data))
         if(response.status_code == 200) :
             return K_AM_success
         else :
@@ -23,11 +28,16 @@ def AM_GetDataSameDevice(id):
     id_url = k_AM_localNodeURL + str(id)   
 
     hConfigurations={
-        'Content-Type': k_AM_contentType
+        'Content-Type': k_AM_contentType,
+    }
+
+    params = {          
+        'AM_Auth_Token': 'Amr Mostafa (Amr_MAM)', 
+        'AM_Auth_Signature': 'AM-from-Python',
     }
 
     try:
-        response  = _req.request(k_AM_GET, id_url, headers=hConfigurations)
+        response  = _req.request(k_AM_GET, id_url, headers=hConfigurations, params=params)
         return response.text
     except:
         return k_AM_failed_to_connect
@@ -43,11 +53,16 @@ def AM_SendData(id, node_red_url, data):
         id_url = str(node_red_url) + "/" + str(id)
 
     hConfigurations={
-        'Content-Type': k_AM_contentType
+        'Content-Type': k_AM_contentType,
     }
     
+    params = {          
+        'AM_Auth_Token': 'Amr Mostafa (Amr_MAM)', 
+        'AM_Auth_Signature': 'AM-from-Python',
+    }
+
     try:
-        response  = _req.request(k_AM_SEND, id_url, headers=hConfigurations, data = str(data))
+        response  = _req.request(k_AM_SEND, id_url, headers=hConfigurations, params=params, data = str(data))
         if(response.status_code == 200) :
             return K_AM_success
         else :
@@ -66,11 +81,16 @@ def AM_GetData(id, node_red_url):
         id_url = str(node_red_url) + "/" + str(id)
 
     hConfigurations={
-        'Content-Type': k_AM_contentType
+        'Content-Type': k_AM_contentType,
+    }
+
+    params = {          
+        'AM_Auth_Token': 'Amr Mostafa (Amr_MAM)', 
+        'AM_Auth_Signature': 'AM-from-Python',
     }
 
     try:
-        response  = _req.request(k_AM_GET, id_url, headers=hConfigurations)
+        response  = _req.request(k_AM_GET, id_url, headers=hConfigurations, params=params)
         return response.text
     except:
         return k_AM_failed_to_connect
